@@ -790,7 +790,7 @@ static void EncodeIptcProfile(FILE *file,const StringInfo *profile)
     dataset=GetStringInfoDatum(profile)[i++];
     record=GetStringInfoDatum(profile)[i++];
     value=(IptcValue *) NULL;
-    for (j=0; j < count; j++)
+    for (j=0; j < (ssize_t) count; j++)
     {
       if ((values[j]->record == record) && (values[j]->dataset == dataset))
         value=values[j];
@@ -801,7 +801,7 @@ static void EncodeIptcProfile(FILE *file,const StringInfo *profile)
           sizeof(*values));
         if (values == (IptcValue **) NULL)
           break;
-        value=AcquireMagickMemory(sizeof(*value));
+        value=(IptcValue *) AcquireMagickMemory(sizeof(*value));
         if (value == (IptcValue *) NULL)
           break;
         /* Check the tag length in IptcValue when a new tag is added */
@@ -894,7 +894,7 @@ static void EncodeIptcProfile(FILE *file,const StringInfo *profile)
   }
   if (values != (IptcValue **) NULL)
     {
-      for (i=0; i < count; i++)
+      for (i=0; i < (ssize_t) count; i++)
       {
         value=values[i];
         (void) FormatLocaleFile(file,"        \"%s[%.20g,%.20g]\": ",
@@ -904,7 +904,7 @@ static void EncodeIptcProfile(FILE *file,const StringInfo *profile)
         else
           {
             (void) FormatLocaleFile(file,"[");
-            for (j=0; j < value->values_length; j++)
+            for (j=0; j < (ssize_t) value->values_length; j++)
             {
               for (k=0; value->values[j][k] != (char *) NULL; k++)
               {
@@ -1475,12 +1475,12 @@ static MagickBooleanType EncodeImageAttributes(Image *image,FILE *file)
       (double) image->page.width,(double) image->page.height,
       (double) image->page.x,(double) image->page.y);
   if ((image->page.x != 0) || (image->page.y != 0))
-    (void) FormatLocaleFile(file,"    \"originGeometry\": %+.20g%+.20g\n",
+    (void) FormatLocaleFile(file,"    \"originGeometry\": %+.20g%+.20g,\n",
       (double) image->page.x,(double) image->page.y);
   JsonFormatLocaleFile(file,"    \"dispose\": %s,\n",
     CommandOptionToMnemonic(MagickDisposeOptions,(ssize_t) image->dispose));
   if (image->delay != 0)
-    (void) FormatLocaleFile(file,"    \"delay\": \"%.20gx%.20g\"\n",
+    (void) FormatLocaleFile(file,"    \"delay\": \"%.20gx%.20g\",\n",
       (double) image->delay,(double) image->ticks_per_second);
   if (image->iterations != 1)
     (void) FormatLocaleFile(file,"    \"iterations\": %.20g,\n",(double)
@@ -1598,9 +1598,7 @@ static MagickBooleanType EncodeImageAttributes(Image *image,FILE *file)
       /*
         Display clipping path.
       */
-      (void) FormatLocaleFile(file,"    \"clipping path\":\n");
-      JsonFormatLocaleFile(file,"%s",value);
-      (void) FormatLocaleFile(file,",\n");
+      JsonFormatLocaleFile(file,"    \"clipping path\": %s,\n",value);
     }
   ResetImageProfileIterator(image);
   name=GetNextImageProfile(image);
